<?php

namespace Drupal\nominatim_geocoder\Plugin\geolocation\Geocoder;

use Drupal\geolocation\GeocoderBase;
use Drupal\geolocation\GeocoderInterface;
use Drupal\Component\Serialization\Json;
use GuzzleHttp\Exception\RequestException;
use Drupal\Core\Url;
use Drupal\Core\Render\BubbleableMetadata;

/**
 * Provides the Nominatim API.
 *
 * @Geocoder(
 *   id = "nominatim",
 *   name = @Translation("Nominatim"),
 *   description = @Translation("See https://wiki.openstreetmap.org/wiki/Nominatim for details."),
 *   frontendCapable = true,
 * )
 */
class Nominatim extends GeocoderBase implements GeocoderInterface {

  protected static $nominatimBaseUrl = 'https://nominatim.openstreetmap.org';

  /**
   * {@inheritdoc}
   */
  protected function getDefaultSettings() {
    $default_settings = parent::getDefaultSettings();

    $default_settings['location_priority'] = [
      'lat' => '',
      'lng' => '',
    ];

    return $default_settings;
  }

  /**
   * {@inheritdoc}
   */
  public function getOptionsForm() {

    $settings = $this->getSettings();

    $form = parent::getOptionsForm();

    $form['location_priority'] = [
      '#type' => 'geolocation_input',
      '#title' => $this->t('Location Priority'),
      '#default_value' => [
        'lat' => $settings['location_priority']['lat'],
        'lng' => $settings['location_priority']['lng'],
      ],
    ];

    return $form;
  }


  /**
   * @param array $render_array
   * @param string $element_name
   *
   * @return array|void|null
   */
  public function formAttachGeocoder(array &$render_array, $element_name) {
    parent::formAttachGeocoder($render_array, $element_name); // TODO: Change the autogenerated stub
    $settings = $this->getSettings();


    $render_array['#attached'] = BubbleableMetadata::mergeAttachments(
      empty($render_array['#attached']) ? [] : $render_array['#attached'],
      [
        'library' => [
          'nominatim_geocoder/geocoder.nominatim',
        ],
        'drupalSettings' => [
          'geolocation' => [
            'geocoder' => [
              $this->getPluginId() => [
                'locationPriority' => [
                  'lat' => $settings['location_priority']['lat'],
                  'lon' => $settings['location_priority']['lng'],
                ],
              ],
            ],
          ],
        ],
      ]
    );
  }

}
